"""
Command-line interface for OLX database migrations.
"""
import argparse
import os
import sys
from pathlib import Path

from alembic import command
from alembic.config import Config

def get_alembic_config():
    """Get the alembic configuration."""
    # Get the directory where this file is located
    package_dir = Path(__file__).parent.absolute()
    
    # Path to alembic.ini
    alembic_ini = package_dir / "alembic.ini"
    
    # Create alembic config
    config = Config(str(alembic_ini))
    
    return config

def migrate():
    """Apply all pending migrations."""
    try:
        config = get_alembic_config()
        command.upgrade(config, "head")
        print("Migrations applied successfully.")
    except Exception as e:
        print(f"Error applying migrations: {e}", file=sys.stderr)
        sys.exit(1)

def make_migrations(args=None):
    """Create a new migration."""
    if args is None:
        parser = argparse.ArgumentParser(description="Create a new migration.")
        parser.add_argument("message", help="Migration message")
        args = parser.parse_args()
    
    try:
        config = get_alembic_config()
        command.revision(config, message=args.message, autogenerate=True)
        print(f"Migration created successfully with message: {args.message}")
    except Exception as e:
        print(f"Error creating migration: {e}", file=sys.stderr)
        sys.exit(1)

if __name__ == "__main__":
    # If script is run directly, show help
    print("This module provides CLI commands for OLX database migrations.")
    print("Use 'olx-db-migrate' to apply migrations.")
    print("Use 'olx-db-makemigrations \"message\"' to create a new migration.") 